import fsub.fsub as fsub


# External interface
def run(args):
    fsub.run(args)
